validate

Function validate 

pub fn validate(acr: &str) -> Result<(), Error>
Validate the format of an Authentication Context Class Reference, as defined in the OpenID Connect specification.

The specification does not define an allowable character set for ACR values. Because the acr_values query parameter accepts them as a space-separated list, this function validates that the ACR is not empty and contains no whitespace.